malli.json-schema


-join-refclj/s

(-join-ref prefix suffix)
source

-refclj/s

(-ref schema
      {:malli.json-schema/keys [transform definitions definitions-path]
       :or {definitions-path "#/definitions/"}
       :as options})
source

-schemaclj/s

(-schema schema {:malli.json-schema/keys [transform] :as options})
source

-transformclj/s

(-transform ?schema options)
source

acceptclj/smultimethod

source

JsonSchemaclj/sprotocol

-acceptclj/s

(-accept this children options)

transforms schema to JSON Schema

transforms schema to JSON Schema
source

selectclj/s

(select m)
source

transformclj/s

(transform ?schema)
(transform ?schema options)

Convert a malli schema to equivalent JSON-Schema Draft 2020-12.

Returns a clojure map that needs to be serialised to JSON separately.

Convert a malli schema to equivalent JSON-Schema Draft 2020-12.

Returns a clojure map that needs to be serialised to JSON separately.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries