malli.transform


*max-compile-depth*clj/s

source

+date->string-format+clj

source

+string->date-format+clj

source

-add-child-compilersclj/s

(-add-child-compilers x-coders)
source

-any->anyclj/s

(-any->any x)
source

-any->stringclj/s

(-any->string x)
source

-base-json-decodersclj/s

(-base-json-decoders)
source

-base-json-encodersclj/s

(-base-json-encoders)
source

-date->stringclj/s

(-date->string x)
source

-infer-child-compilerclj/s

(-infer-child-compiler x-coders)
source

-interceptorclj/s

(-interceptor ?interceptor schema options)

Utility function to convert input into an interceptor. Works with functions, map and sequence of those.

Utility function to convert input into an interceptor. Works with functions,
map and sequence of those.
sourceraw docstring

-json-decodersclj/s

(-json-decoders)
source

-json-encodersclj/s

(-json-encoders)
source

-number->doubleclj/s

(-number->double x)
source

-number->floatclj/s

(-number->float x)
source

-number->longclj/s

(-number->long x)
source

-safeclj/s

(-safe f)
source

-sequential->setclj/s

(-sequential->set x)
source

-sequential->vectorclj/s

(-sequential->vector x)
source

-sequential-or-set->seqclj/s

(-sequential-or-set->seq x)
source

-sequential-or-set->vectorclj/s

(-sequential-or-set->vector x)
source

-string->booleanclj/s

(-string->boolean x)
source

-string->dateclj/s

(-string->date x)
source

-string->decimalclj

(-string->decimal x)
source

-string->doubleclj/s

(-string->double x)
source

-string->floatclj/s

(-string->float x)
source

-string->keywordclj/s

(-string->keyword x)
source

-string->longclj/s

(-string->long x)
source

-string->nilclj/s

(-string->nil x)
source

-string->symbolclj/s

(-string->symbol x)
source

-string->uriclj

(-string->uri x)
source

-string->uuidclj/s

(-string->uuid x)
source

-string-decodersclj/s

(-string-decoders)
source

-string-encodersclj/s

(-string-encoders)
source

-transform-if-validclj/s

(-transform-if-valid f schema)
source

-transform-map-keysclj/s

(-transform-map-keys f)
(-transform-map-keys ks f)
source

collection-transformerclj/s

(collection-transformer)
source

default-value-transformerclj/s

(default-value-transformer)
(default-value-transformer {:keys [key default-fn defaults
                                   :malli.transform/add-optional-keys]
                            :or {key :default default-fn (fn [_ x] x)}})
source

json-transformerclj/s

(json-transformer)
(json-transformer {:malli.transform/keys [json-vectors keywordize-map-keys
                                          map-of-key-decoders]
                   :or {map-of-key-decoders (-string-decoders)}})
source

key-transformerclj/s

(key-transformer {:keys [decode encode types] :or {types #{:map}}})
source

parse-floatclj/s

(parse-float s)
source

string-transformerclj/s

(string-transformer)
source

strip-extra-keys-transformerclj/s≠

clj
(strip-extra-keys-transformer)
(strip-extra-keys-transformer
  {:keys [accept]
   :or {accept (m/-comp (fn* [p1__13785#]
                             (or (nil? p1__13785#) (true? p1__13785#)))
                        :closed
                        m/properties)}})
cljs
(strip-extra-keys-transformer)
(strip-extra-keys-transformer
  {:keys [accept]
   :or {accept (m/-comp (fn* [p1__19006#]
                             (or (nil? p1__19006#) (true? p1__19006#)))
                        :closed
                        m/properties)}})
source

transformerclj/s

(transformer & ?transformers)

Compose a number of transformers. Takes a sequence of Transformer objects or transformer maps. Returns a Transformer object.

A transformer map has the shape {:name <keyword> :decoders <map from schema to function> :encoders <map from schema to function>}

Compose a number of transformers. Takes a sequence of Transformer objects or transformer maps.
Returns a Transformer object.

A transformer map has the shape
{:name <keyword>
 :decoders <map from schema to function>
 :encoders <map from schema to function>}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries