(-ref schema
{:malli.json-schema/keys [transform definitions definitions-path]
:or {definitions-path "#/definitions/"}
:as options})(-accept this children options)transforms schema to JSON Schema
transforms schema to JSON Schema
(transform ?schema)(transform ?schema options)Convert a malli schema to equivalent JSON-Schema Draft 2020-12.
Returns a clojure map that needs to be serialised to JSON separately.
Convert a malli schema to equivalent JSON-Schema Draft 2020-12. Returns a clojure map that needs to be serialised to JSON separately.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |