(-interceptor ?interceptor schema options)Utility function to convert input into an interceptor. Works with functions, map and sequence of those.
Utility function to convert input into an interceptor. Works with functions, map and sequence of those.
(default-value-transformer)(default-value-transformer {:keys [key default-fn defaults
:malli.transform/add-optional-keys]
:or {key :default default-fn (fn [_ x] x)}})(json-transformer)(json-transformer {:malli.transform/keys [json-vectors keywordize-map-keys
map-of-key-decoders]
:or {map-of-key-decoders (-string-decoders)}})(strip-extra-keys-transformer)(strip-extra-keys-transformer
{:keys [accept]
:or {accept (m/-comp (fn* [p1__13785#]
(or (nil? p1__13785#) (true? p1__13785#)))
:closed
m/properties)}})(strip-extra-keys-transformer)(strip-extra-keys-transformer
{:keys [accept]
:or {accept (m/-comp (fn* [p1__19006#]
(or (nil? p1__19006#) (true? p1__19006#)))
:closed
m/properties)}})(transformer & ?transformers)Compose a number of transformers. Takes a sequence of Transformer objects or transformer maps. Returns a Transformer object.
A transformer map has the shape {:name <keyword> :decoders <map from schema to function> :encoders <map from schema to function>}
Compose a number of transformers. Takes a sequence of Transformer objects or transformer maps.
Returns a Transformer object.
A transformer map has the shape
{:name <keyword>
:decoders <map from schema to function>
:encoders <map from schema to function>}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |